@@ -261,7 +261,7 @@ protected:
 		Package(char *name);
 	};
 public:
-	CCXX_MEMBER_EXPORT(static bool) use(const char *name);
+	static bool use(const char *name);
 
 	/**
 	 * This class holds an "active" session handler that has been created
@@ -476,7 +476,7 @@ private:
 	int keyword_count;
 	int trap_count;
 
-protected:
+public:
 	/**
 	 * Get the method handler associated with a given keyword.  This
 	 * is used by ScriptImage when compiling.
@@ -652,7 +652,6 @@ protected:
 	 */
 	ScriptCommand();
 
-public:
 	virtual	int mapicmp(const char *s1, const char *s2)
 		{return stricmp(s1, s2);};
 
